blohg, a Mercurial-based blogging engine
========================================

:Author: Rafael Goncalves Martins
:Website: http://blohg.org/
:Source code: http://hg.rafaelmartins.eng.br/blohg/
:Mailing list: blohg@librelist.com
:Version: |release|


This is blohg, a full-featured blogging engine, that uses Mercurial as the 
storage backend.

Here you will find a complete documentation about the usage and the concepts
behind blohg.

Have fun, and feel free to contact us, using the mailing list, if you have
any questions.

Enjoy!


User's Guide
------------

.. toctree::
   :maxdepth: 2

   about
   install
   new-blog
   write
   deploy
   upgrade


Additional Notes
----------------

.. toctree::
   :maxdepth: 2

   license

